import request from '@/config/axios'

// 门墩儿-企业信息 VO
export interface EnterpriseVO {
  id: number // id
  name: string // 企业全称
  anotherName: string // 企业别称
  website: string // 企业官网
  introduce: string // 公司简介
  contacts: string // 联系人
  phone: string // 联系电话
  logoUrl: string // logo图片地址
  industryId: number // 所在行业
  financingStatus: number // 融资阶段（未融资，天使轮，A轮，B轮，C轮，D轮以上，已上市，不需要融资）
  scale: number // 人员规模（0-20人，20-99人，100-499人，500-999人，1000-9999人，9999人以上）
  welfareList: string // 公司福利
  albumList: string // 公司相册
  workTime: string // 上班时间
  developHistory: string // 发展历程
  receivedHonors: string // 获得荣誉
  parentId: number // 上级id
}

// 门墩儿-企业信息 API
export const EnterpriseApi = {
  // 查询门墩儿-企业信息分页
  getEnterprisePage: async (params: any) => {
    return await request.get({ url: `/menduner/system/enterprise/page`, params })
  },

  // 查询门墩儿-企业信息详情
  getEnterprise: async (id: number) => {
    return await request.get({ url: `/menduner/system/enterprise/get?id=` + id })
  },

  // 新增门墩儿-企业信息
  createEnterprise: async (data: EnterpriseVO) => {
    return await request.post({ url: `/menduner/system/enterprise/create`, data })
  },

  // 修改门墩儿-企业信息
  updateEnterprise: async (data: EnterpriseVO) => {
    return await request.put({ url: `/menduner/system/enterprise/update`, data })
  },

  // 删除门墩儿-企业信息
  deleteEnterprise: async (id: number) => {
    return await request.delete({ url: `/menduner/system/enterprise/delete?id=` + id })
  },

  // 导出门墩儿-企业信息 Excel
  exportEnterprise: async (params) => {
    return await request.download({ url: `/menduner/system/enterprise/export-excel`, params })
  },

  // 获得企业基本信息
  getEnterpriseInfo: async (id: string) => {
    return await request.get({ url: `/menduner/system/enterprise/get?id=${id}` })
  },

  // 获得企业工商信息
  getEnterpriseBusinessInfo: async (id: string) => {
    return await request.get({ url: `/menduner/system/enterprise-business/get/by?enterpriseId=${id}` })
  },

  // 获得下级企业分页
  getSubordinateEnterprisesPage: async (params) => {
    return await request.get({ url: `/menduner/system/enterprise/page`, params })
  },

  // 获得企业岗位信息分页
  getEnterprisePostPage: async (params) => {
    return await request.get({ url: `/menduner/system/enterprise-post/page`, params })
  },

  // 获得企业登录用户分页
  getEnterpriseUserPage: async (params) => {
    return await request.get({ url: `/menduner/system/enterprise-user-bind/page`, params })
  },

  // 更新企业发布职位类型权限
  updateEnterpriseJobType: async (data) => {
    return await request.put({ url: `/menduner/system/enterprise/update/pub-job-type-perm`, data })
  },

  // 企业信息编辑
  updateEnterpriseInfo: async (data) => {
    return await request.put({ url: `/menduner/system/enterprise/update`, data })
  },

  // 获取企业招聘职位
  getEnterpriseJobPage: async (params) => {
    return await request.get({ url: `/menduner/system/job-advertised/page`, params })
  },

  // 企业职位刷新
  refreshEnterpriseJob: async (ids: array) => {
    return await request.post({ url: `/menduner/system/job-advertised/refresh?ids=${ids}` })
  },

  // 企业职位开启
  openEnterpriseJob: async (ids: array) => {
    return await request.post({ url: `/menduner/system/job-advertised/enable?ids=${ids}` })
  },

  // 企业职位刷新
  closeEnterpriseJob: async (ids: array) => {
    return await request.post({ url: `/menduner/system/job-advertised/disable?ids=${ids}` })
  },

  // 职位删除
  deleteJob: async (id: string) => {
    return await request.delete({ url: `/menduner/system/job-advertised/delete?id=${id}` })
  }
}