import request from '@/config/axios'

// 职位信息 VO
export interface PositionVO {
  id: number // id
  nameCn: string // 职位中文名称
  nameEn: string // 职位英文名称
  parentId: number // 上级id
  level: boolean // 层级
  requirement: string // 默认职位要求
  content: string // 默认职位描述内容
}

// 职位信息 API
export const PositionApi = {
  // 查询职位信息列表
  getPositionList: async (params) => {
    return await request.get({ url: `/menduner/system/position/list`, params })
  },

  // 查询职位信息详情
  getPosition: async (id: number) => {
    return await request.get({ url: `/menduner/system/position/get?id=` + id })
  },

  // 新增职位信息
  createPosition: async (data: PositionVO) => {
    return await request.post({ url: `/menduner/system/position/create`, data })
  },

  // 修改职位信息
  updatePosition: async (data: PositionVO) => {
    return await request.put({ url: `/menduner/system/position/update`, data })
  },

  // 删除职位信息
  deletePosition: async (id: number) => {
    return await request.delete({ url: `/menduner/system/position/delete?id=` + id })
  },

  // 导出职位信息 Excel
  exportPosition: async (params) => {
    return await request.download({ url: `/menduner/system/position/export-excel`, params })
  }
}