import request from '@/config/axios'

// 学校 VO
export interface SchoolVO {
  id: number // id
  name: string // 学校名称
  areaId: number // 学校所在区域
  address: string // 学校所在地址
  longitude: string // 经度
  latitude: string // 维度
  status: number // 帐号状态（0正常 1停用）
}

// 学校 API
export const SchoolApi = {
  // 查询学校分页
  getSchoolPage: async (params: any) => {
    return await request.get({ url: `/menduner/system/school/page`, params })
  },

  // 查询学校详情
  getSchool: async (id: number) => {
    return await request.get({ url: `/menduner/system/school/get?id=` + id })
  },

  // 新增学校
  createSchool: async (data: SchoolVO) => {
    return await request.post({ url: `/menduner/system/school/create`, data })
  },

  // 修改学校
  updateSchool: async (data: SchoolVO) => {
    return await request.put({ url: `/menduner/system/school/update`, data })
  },

  // 删除学校
  deleteSchool: async (id: number) => {
    return await request.delete({ url: `/menduner/system/school/delete?id=` + id })
  },

  // 导出学校 Excel
  exportSchool: async (params) => {
    return await request.download({ url: `/menduner/system/school/export-excel`, params })
  }
}